@@ -2,7 +2,7 @@ package sources
 
 import (
 	"errors"
-	"fmt"
+	"strings"
 	"sync"
 )
 
@@ -20,6 +20,10 @@ func NewScanErrors() *ScanErrors {
 
 // Add an error to the collection in a thread-safe manner.
 func (s *ScanErrors) Add(err error) {
+	if err == nil {
+		return
+	}
+
 	s.mu.Lock()
 	defer s.mu.Unlock()
 	s.errors = append(s.errors, err)
@@ -35,7 +39,17 @@ func (s *ScanErrors) Count() uint64 {
 func (s *ScanErrors) String() string {
 	s.mu.RLock()
 	defer s.mu.RUnlock()
-	return fmt.Sprintf("%v", s.errors)
+
+	var sb strings.Builder
+	sb.WriteString("[")
+	for i, err := range s.errors {
+		sb.WriteString(`"` + err.Error() + `"`)
+		if i < len(s.errors)-1 {
+			sb.WriteString(", ")
+		}
+	}
+	sb.WriteString("]")
+	return sb.String()
 }
 
 func (s *ScanErrors) Errors() error {
